/*
 * Copyright 2020 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package androidx.compose.material.icons.rounded

import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.materialIcon
import androidx.compose.material.icons.materialPath
import androidx.compose.ui.graphics.vector.VectorAsset

val Icons.Rounded.LinkedCamera: VectorAsset
    get() {
        if (_linkedCamera != null) {
            return _linkedCamera!!
        }
        _linkedCamera = materialIcon {
            materialPath {
                moveTo(12.0f, 14.0f)
                moveToRelative(-3.0f, 0.0f)
                arcToRelative(3.0f, 3.0f, 0.0f, true, true, 6.0f, 0.0f)
                arcToRelative(3.0f, 3.0f, 0.0f, true, true, -6.0f, 0.0f)
            }
            materialPath {
                moveTo(16.6f, 3.37f)
                curveToRelative(2.1f, 0.27f, 3.77f, 1.93f, 4.03f, 4.03f)
                curveToRelative(0.04f, 0.34f, 0.32f, 0.6f, 0.66f, 0.6f)
                curveToRelative(0.39f, 0.0f, 0.71f, -0.34f, 0.66f, -0.73f)
                curveToRelative(-0.33f, -2.72f, -2.5f, -4.89f, -5.22f, -5.22f)
                curveToRelative(-0.39f, -0.05f, -0.73f, 0.27f, -0.73f, 0.66f)
                curveToRelative(0.0f, 0.34f, 0.26f, 0.62f, 0.6f, 0.66f)
                close()
                moveTo(19.23f, 7.19f)
                curveTo(18.93f, 6.0f, 18.0f, 5.07f, 16.81f, 4.77f)
                curveToRelative(-0.41f, -0.1f, -0.81f, 0.22f, -0.81f, 0.65f)
                curveToRelative(0.0f, 0.29f, 0.19f, 0.57f, 0.48f, 0.64f)
                curveToRelative(0.72f, 0.18f, 1.29f, 0.74f, 1.46f, 1.46f)
                curveToRelative(0.07f, 0.29f, 0.34f, 0.48f, 0.64f, 0.48f)
                curveToRelative(0.43f, 0.0f, 0.75f, -0.4f, 0.65f, -0.81f)
                close()
                moveTo(17.0f, 9.0f)
                curveToRelative(0.0f, -1.1f, -0.9f, -2.0f, -2.0f, -2.0f)
                lineTo(15.0f, 5.0f)
                curveToRelative(0.0f, -0.55f, -0.45f, -1.0f, -1.0f, -1.0f)
                lineTo(9.88f, 4.0f)
                curveToRelative(-0.56f, 0.0f, -1.1f, 0.24f, -1.48f, 0.65f)
                lineTo(7.17f, 6.0f)
                lineTo(4.0f, 6.0f)
                curveToRelative(-1.1f, 0.0f, -2.0f, 0.9f, -2.0f, 2.0f)
                verticalLineToRelative(12.0f)
                curveToRelative(0.0f, 1.1f, 0.9f, 2.0f, 2.0f, 2.0f)
                horizontalLineToRelative(16.0f)
                curveToRelative(1.1f, 0.0f, 2.0f, -0.9f, 2.0f, -2.0f)
                verticalLineToRelative(-9.0f)
                curveToRelative(0.0f, -1.1f, -0.9f, -2.0f, -2.0f, -2.0f)
                horizontalLineToRelative(-3.0f)
                close()
                moveTo(12.0f, 19.0f)
                curveToRelative(-2.76f, 0.0f, -5.0f, -2.24f, -5.0f, -5.0f)
                reflectiveCurveToRelative(2.24f, -5.0f, 5.0f, -5.0f)
                reflectiveCurveToRelative(5.0f, 2.24f, 5.0f, 5.0f)
                reflectiveCurveToRelative(-2.24f, 5.0f, -5.0f, 5.0f)
                close()
            }
        }
        return _linkedCamera!!
    }

private var _linkedCamera: VectorAsset? = null
